<?php

namespace Drupal\auctioneer_commerce;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\auctioneer\AuctionTypeManagerInterface;
use Drupal\auctioneer\Entity\AuctionTypeInterface;

/**
 * Provides managing service for auction commerce integration.
 */
class AuctionCommerceManager implements AuctionCommerceManagerInterface {

  use StringTranslationTrait;

  /**
   * The entity field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The auction type manager.
   *
   * @var \Drupal\auctioneer\AuctionTypeManagerInterface
   */
  protected $auctionTypeManager;

  /**
   * Constructor method.
   *
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\auctioneer\AuctionTypeManagerInterface $auction_type_manager
   *   The auction type manager.
   */
  public function __construct(EntityFieldManagerInterface $entity_field_manager, AuctionTypeManagerInterface $auction_type_manager) {
    $this->entityFieldManager = $entity_field_manager;
    $this->auctionTypeManager = $auction_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function initializeAuctionTypeCommerceConfigurations(AuctionTypeInterface $auction_type, bool $lock_fields = TRUE) {
    $settings = $auction_type->getThirdPartySetting('auctioneer_commerce', 'settings');
    if (empty($settings) || !isset($settings['bid_amount_field_name']) || !isset($settings['enable']) || (isset($settings['enable']) && !(bool) $settings['enable'])) {
      return;
    }
    $fields = [
      'auction_commerce_store' => BaseFieldDefinition::create('entity_reference')
        ->setLabel($this->t('Store'))
        ->setDescription($this->t('The auction store.'))
        ->setCardinality(1)
        ->setRequired(TRUE)
        ->setSetting('target_type', 'commerce_store')
        ->setSetting('handler', 'default')
        ->setDisplayOptions('form', [
          'type' => 'commerce_entity_select',
        ])
        ->setDisplayConfigurable('form', TRUE)
        ->setDisplayConfigurable('view', TRUE),
      'auction_commerce_currency' => BaseFieldDefinition::create('entity_reference')
        ->setLabel($this->t('Currency'))
        ->setDescription($this->t('The auction currency.'))
        ->setCardinality(1)
        ->setRequired(TRUE)
        ->setSetting('target_type', 'commerce_currency')
        ->setSetting('handler', 'default')
        ->setTranslatable(TRUE)
        ->setDisplayOptions('form', [
          'type' => 'options_select',
        ])
        ->setDisplayConfigurable('view', TRUE)
        ->setDisplayConfigurable('form', TRUE),
    ];
    $auction_field_manager = $this->auctionTypeManager->auctionFieldManager();
    $auction_field_manager->provideEntityTypeFields($fields, 'auction', $auction_type->id(), $lock_fields);
  }

  /**
   * {@inheritdoc}
   */
  public function isCommerceEnabled(AuctionTypeInterface $auction_type) : bool {
    $enabled = FALSE;
    $field_definitions = $this->entityFieldManager->getFieldDefinitions('auction', $auction_type->id());
    if (isset($field_definitions['auction_commerce_store']) || isset($field_definitions['auction_commerce_currency'])) {
      $enabled = TRUE;
    }

    return $enabled;
  }

}
